<template>
  <div class="bbsl-common-page" @click="commonPageClick">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="合同名称">
              <el-input maxlength="128" clearable v-model="querys[1].value" placeholder="请输入合同名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="合同类型">
              <el-select clearable v-model="querys[2].value" placeholder="请选择合同类型">
                <el-option v-for="item in contractTypes" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="合同状态">
              <el-select clearable v-model="querys[3].value" placeholder="请选择合同状态">
                <el-option v-for="item in contractStatusList" :key="item.value" :label="item.label"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" @click="handleSearch" icon="el-icon-search">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
            style="margin-left: 10px" type="danger">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="130" fixed prop="contractCode" label="合同编码" show-overflow-tooltip></el-table-column>
        <el-table-column fixed min-width="150" prop="contractName" label="合同名称" show-overflow-tooltip></el-table-column>
        <el-table-column width="90" prop="personLiable" label="责任人" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="110" prop="signDate" label="合同签订时间" show-overflow-tooltip>
        </el-table-column>
        <el-table-column width="90" prop="contractType" label="合同类型" show-overflow-tooltip>
          <template #default="scope">
            <div>
              {{
                scope.row.contractType == 1
                  ? '采购合同'
                  : scope.row.contractType == 2
                    ? '建设合同'
                    : '运维合同'
              }}
            </div>
          </template>
        </el-table-column>
        <el-table-column width="110" prop="startDate" label="合同开始时间" show-overflow-tooltip></el-table-column>
        <el-table-column width="110" prop="endDate" label="合同结束时间" show-overflow-tooltip></el-table-column>
        <el-table-column width="80" prop="contractStatus" label="合同状态" show-overflow-tooltip>
          <template #default="scope">
            <div>
              {{ scope.row.contractStatus == 1 ? '进行中' : '已完成' }}
            </div>
          </template>
        </el-table-column>
        <el-table-column min-width="120" prop="companyName" label="供应商" show-overflow-tooltip></el-table-column>
        <!-- <el-table-column
		  min-width="110"
		  
		  prop=""
		  label="预警状态"
		  show-overflow-tooltip
		></el-table-column> -->
        <el-table-column min-width="90" prop="" label="操作" show-overflow-tooltip>
          <template #default="scope">
            <el-button @click="handleEquipment(scope.row)" size="small">关联设备</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" align="right" class="bbsl-pagination" background
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
        :total="total"></el-pagination>
    </div>
    <!-- 新增修改弹窗 -->
    <contractManageDialog ref="formModal"></contractManageDialog>
    <!-- <relatedEquimentDialog
      v-if="showFormDia"
      @closeFormDia="closeFormDia"
      @refList="loadData"
      :showFormDia="showFormDia"
      :pId="pId"
    ></relatedEquimentDialog> -->
  </div>
</template>
<script>
import req from '@/api/device/contractManage.js'
import contractManageDialog from '@/views/Device/resourceManage/components/contractManageDialog'
// import relatedEquimentDialog from '@/views/Device/resourceManage/components/relatedEquimentDialog'
import { TableMixin } from '@/mixins/tableMixin'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import { ExtendParamsMixin } from '@/mixins/extendParams.js'
export default {
  name: 'ContractManage',
  mixins: [TableMixin, ExtendParamsMixin],
  components: {
    contractManageDialog,
    // relatedEquimentDialog
  },
  data() {
    return {
      showFormDia: false, //关联设备弹窗显示
      title: '', //关联设备弹窗标题
      pId: '', //修改时传的id值
      url: {
        delete: '/device/base/contract/',
      }, //删除信息url
      contractTypes: [], //合同类型列表
      contractStatusList: [
        { value: 1, label: '进行中' },
        { value: 2, label: '已完成' },
      ], //合同状态列表
      showMore: false, //展开搜索更多
      companyName: '',
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'contractCode',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'contractName',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'contractType',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'contractStatus',
          relation: 'AND',
          value: '',
        },
      ],
    }
  },
  created() {
    this.contractTypes = dictContracts.getDictItemsFromCache('htlx')
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    // 获取所有合同信息
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      req.contractQuery(this.queryParam).then((res) => {
        // console.log(res,'合同信息')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      this.$refs.formModal.edit(row)
    },
    // 打开搜索更多
    openMore() {
      this.showMore = !this.showMore
    },
    // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    // 打开关联设备弹窗
    handleEquipment(val) {
      let path = this.$route.path
      if (path.indexOf('frontPlat') !== -1) {
        this.$router.push({
          name: 'relatedEquiment',
          query: val,
        })
      } else {
        this.$router.push({
          name: 'relatedEquimentLink',
          query: val,
        })
      }
    },
    closeFormDia() {
      this.showFormDia = false
    },
  },
}
</script>

<style lang="scss" scoped>
.btn-content {
  display: flex;
}

.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}

.el-select-dropdown__item {
  color: #9a9a9a !important;
}

.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}

.btn-content :first-child {
  margin: 0 0 0 0 !important;
}

.el-switch__label--left {
  position: relative;
  left: 45px;
  color: #fff;
  z-index: -1111;
}

.el-switch__core {
  width: 50px !important;
}

.el-switch__label--right {
  position: relative;
  right: 46px;
  color: #fff;
  z-index: -1111;
}

.el-switch__label--right.is-active {
  z-index: 1111;
  color: #fff !important;
}

.el-switch__label--left.is-active {
  z-index: 1111;
  color: #9c9c9c !important;
}

.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}

::-webkit-scrollbar {
  background: #fff !important;
}

.bbsl-pagination {
  bottom: 10px !important;
}

.success_class {
  td {
    div {
      color: red !important;
    }
  }
}

.error_class {
  td {
    div {
      color: rgb(185, 185, 0) !important;
    }
  }
}

.bbsl-search-more {
  width: calc(50% + 40px);
  padding: 20px 20px 20px 20px;
  background-color: #fff;
  box-shadow: 0px 4px 6px 0 rgba($color: #000000, $alpha: 0.1);
  position: absolute;
  z-index: 999;
  right: 0;
  top: 66px;
  border: 1px solid #ccc;
  box-sizing: border-box;
}
</style>
